@@ -323,6 +323,38 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
     local("git commit -am 'add results of build' --no-verify --quiet")
 
 
+@task
+def build2():
+
+
+    # ensure yarn installs all build tools
+    local("pwd")
+    local('mvn clean install -DskipTests')
+    local('mkdir -p deploy/api')
+    local('mkdir -p deploy/worker')
+
+    local('cp config/ deploy/api/config')
+ 
+    local('cp config/keyset-prod.json deploy/api/config/keyset.json')
+    local('cp config/logback.xml deploy/api/config/')
+    local('cp config/application-prod.yml deploy/api/config/')
+
+    local('cp -r api/target/lib/ deploy/api/')
+    
+    local('cp api/target/*SNAPSHOT.jar deploy/api/')
+
+    local('cp config/keyset-prod.json deploy/worker/config/keyset.json')
+    local('cp config/logback.xml deploy/worker/config/')
+    local('cp config/application-prod-worker.yml deploy/worker/config/')
+
+    local('cp -r worker/target/lib/ deploy/worker/')
+
+    local('cp worker/target/*SNAPSHOT.jar deploy/worker/')
+
+
+
+
+
 # Obtain git_sha from Jenkins git plugin, make sure it's passed along with the code so that
 # uwsgi, djangorq, and and celery can make use of it (e.g. to pass to
 # Sentry for releases)
@@ -334,19 +366,23 @@ def set_git_sha():
 
 
 @task
-def tar_from_git(branch, dirs=None):
-    local("pwd")
-    if dirs:
-        local('tar -czf %s.tar.gz %s' % (TAR_NAME, dirs))
+def tar_from_git(branch, dirs=None, baseDir='.'):
+    
+    with lwd(baseDir):
+        local("pwd")
+        if dirs:
+            local('tar -czf %s.tar.gz %s' % (TAR_NAME, dirs))
 
-    else:
-        local('find . -path ./\.git -prune -o -name \.gitignore -type f -exec rm -f {} \;')
-        local('echo "%s.tar.*" >> .gitignore' % TAR_NAME)
-        local('echo "fabfile.*" >> .gitignore')
-        local('rm -rf %s.tar.gz' % TAR_NAME)
-        local('git archive %s --format=tar.gz --output=%s.tar.gz' %
-              (branch, TAR_NAME))
+        else:
+            local('find . -path ./\.git -prune -o -name \.gitignore -type f -exec rm -f {} \;')
+            local('echo "%s.tar.*" >> .gitignore' % TAR_NAME)
+            local('echo "fabfile.*" >> .gitignore')
+            local('rm -rf %s.tar.gz' % TAR_NAME)
+            local('git archive %s --format=tar.gz --output=%s.tar.gz' %
+                  (branch, TAR_NAME))
 
+    if baseDir != '.':
+        local('mv %s/%s.tar.gz .')
 
 @task
 def clean_up():
@@ -587,8 +623,6 @@ def update_app_utils(appname, branch, keys=False, reboot=False):
         with settings(hide('warnings'), warn_only=True):
             sudo("shutdown -r now")
 
-    local('rm %s.tar.gz' % TAR_NAME)
-
 
 @task
 def swap_code():
